@@ -7,6 +7,7 @@ from enum import Enum
 from dagster import check
 from dagster.core.errors import DagsterInvalidAssetKey
 from dagster.serdes import Persistable, whitelist_for_persistence
+from dagster.utils.backcompat import experimental_arg_warning
 
 from .utils import DEFAULT_OUTPUT
 
@@ -15,7 +16,7 @@ def last_file_comp(path):
     return os.path.basename(os.path.normpath(path))
 
 
-ASSET_KEY_REGEX = re.compile("^[a-zA-Z0-9_]+$")  # alphanumeric, _, -, .
+ASSET_KEY_REGEX = re.compile("^[a-zA-Z0-9_.-]+$")  # alphanumeric, _, -, .
 ASSET_KEY_SPLIT_REGEX = re.compile("[^a-zA-Z0-9_]")
 ASSET_KEY_STRUCTURED_DELIMITER = "."
 
@@ -219,9 +220,20 @@ class EventMetadataEntry(
             label (str): Short display label for this metadata entry.
             description (Optional[str]): A human-readable description of this metadata entry.
         """
-        check.opt_float_param(value, "value")
         return EventMetadataEntry(label, description, FloatMetadataEntryData(value))
 
+    @staticmethod
+    def int(value, label, description=None):
+        """Static constructor for a metadata entry containing int as
+        :py:class:`IntMetadataEntryData`.
+
+        Args:
+            value (Optional[int]): The int value contained by this metadata entry.
+            label (str): Short display label for this metadata entry.
+            description (Optional[str]): A human-readable description of this metadata entry.
+        """
+        return EventMetadataEntry(label, description, IntMetadataEntryData(value))
+
 
 @whitelist_for_persistence
 class TextMetadataEntryData(namedtuple("_TextMetadataEntryData", "text"), Persistable):
@@ -306,12 +318,17 @@ class PythonArtifactMetadataEntryData(
 @whitelist_for_persistence
 class FloatMetadataEntryData(namedtuple("_FloatMetadataEntryData", "value"), Persistable):
     def __new__(cls, value):
-        check.opt_float_param(value, "value")
         return super(FloatMetadataEntryData, cls).__new__(
             cls, check.opt_float_param(value, "value")
         )
 
 
+@whitelist_for_persistence
+class IntMetadataEntryData(namedtuple("_IntMetadataEntryData", "value"), Persistable):
+    def __new__(cls, value):
+        return super(IntMetadataEntryData, cls).__new__(cls, check.opt_int_param(value, "value"))
+
+
 EntryDataUnion = (
     TextMetadataEntryData,
     UrlMetadataEntryData,
@@ -320,10 +337,11 @@ EntryDataUnion = (
     MarkdownMetadataEntryData,
     PythonArtifactMetadataEntryData,
     FloatMetadataEntryData,
+    IntMetadataEntryData,
 )
 
 
-class Output(namedtuple("_Output", "value output_name")):
+class Output(namedtuple("_Output", "value output_name address")):
     """Event corresponding to one of a solid's outputs.
 
     Solid compute functions must explicitly yield events of this type when they have more than
@@ -338,15 +356,26 @@ class Output(namedtuple("_Output", "value output_name")):
         value (Any): The value returned by the compute function.
         output_name (Optional[str]): Name of the corresponding output definition. (default:
             "result")
+        address (str): (Experimental) A string that can be provided to a storage system to
+            store/retrieve the outputted value.
     """
 
-    def __new__(cls, value, output_name=DEFAULT_OUTPUT):
-        return super(Output, cls).__new__(cls, value, check.str_param(output_name, "output_name"))
+    def __new__(cls, value, output_name=DEFAULT_OUTPUT, address=None):
+        if address:
+            experimental_arg_warning("address", "Output.__new__")
+
+        return super(Output, cls).__new__(
+            cls,
+            value,
+            check.str_param(output_name, "output_name"),
+            check.opt_str_param(address, "address"),
+        )
 
 
 @whitelist_for_persistence
 class AssetMaterialization(
-    namedtuple("_AssetMaterialization", "asset_key description metadata_entries"), Persistable
+    namedtuple("_AssetMaterialization", "asset_key description metadata_entries partition"),
+    Persistable,
 ):
     """Event indicating that a solid has materialized an asset.
 
@@ -365,9 +394,10 @@ class AssetMaterialization(
         description (Optional[str]): A longer human-radable description of the materialized value.
         metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the
             materialized value.
+        partition (Optional[str]): The name of the partition that was materialized.
     """
 
-    def __new__(cls, asset_key, description=None, metadata_entries=None):
+    def __new__(cls, asset_key, description=None, metadata_entries=None, partition=None):
         if isinstance(asset_key, AssetKey):
             check.inst_param(asset_key, "asset_key", AssetKey)
         elif check.is_str(asset_key):
@@ -386,6 +416,7 @@ class AssetMaterialization(
             metadata_entries=check.opt_list_param(
                 metadata_entries, metadata_entries, of_type=EventMetadataEntry
             ),
+            partition=check.opt_str_param(partition, "partition"),
         )
 
     @property
@@ -412,7 +443,8 @@ class AssetMaterialization(
 
 @whitelist_for_persistence
 class Materialization(
-    namedtuple("_Materialization", "label description metadata_entries asset_key"), Persistable
+    namedtuple("_Materialization", "label description metadata_entries asset_key partition"),
+    Persistable,
 ):
     """Event indicating that a solid has materialized a value.
 
@@ -431,6 +463,7 @@ class Materialization(
             materialized value.
         asset_key (Optional[str|AssetKey]): An optional parameter to identify the materialized asset
             across pipeline runs
+        partition (Optional[str]): The name of the partition that was materialized.
     """
 
     def __new__(
@@ -439,6 +472,7 @@ class Materialization(
         description=None,
         metadata_entries=None,
         asset_key=None,
+        partition=None,
         skip_deprecation_warning=False,
     ):
         if asset_key and check.is_str(asset_key):
@@ -465,6 +499,7 @@ class Materialization(
                 metadata_entries, metadata_entries, of_type=EventMetadataEntry
             ),
             asset_key=asset_key,
+            partition=check.opt_str_param(partition, "partition"),
         )
 
     @staticmethod
