@@ -1,4 +1,4 @@
-'''
+"""
 
 Dagster Contexts
 
@@ -11,7 +11,7 @@ The inheritance structure of contexts is currently as follows:
  construct_pipeline_execution_context()
  |
  V
-SystemPipelineExecutionContext                  (contains SystemPipelineExecutionContextData)
+SystemPipelineExecutionContext                  (contains SystemExecutionContextData)
  |
  |--> SystemStepExecutionContext                (produced by .for_step() on pipeline context)
        |
@@ -30,11 +30,11 @@ StepExecutionContext
  |                -------------------------------------------
  |                |                                         |
  |                V                                         V
- |--> ComputeExecutionContext              DagstermillInNotebookExecutionContext
+ |--> SolidExecutionContext              DagstermillInNotebookExecutionContext
                                              (defined in dagstermill)
 
 ====================================================================================================
 These contexts exist so that we can add system-defined stuff to the System* contexts without
 exposing them to users. System*Context classes are totally internal, whereas
-ComputeExecutionContext et all are passed to the user and exported at the global level.
-'''
+SolidExecutionContext et all are passed to the user and exported at the global level.
+"""
