@@ -2,16 +2,11 @@ from collections import namedtuple
 from enum import Enum
 
 from dagster import check
-from dagster.core.definitions import (
-    AssetMaterialization,
-    HookDefinition,
-    Materialization,
-    SolidHandle,
-)
+from dagster.core.definitions import AssetMaterialization, Materialization, Solid, SolidHandle
 from dagster.core.definitions.events import EventMetadataEntry
 from dagster.core.types.dagster_type import DagsterType
 from dagster.serdes import whitelist_for_serdes
-from dagster.utils import frozentags, merge_dicts
+from dagster.utils import merge_dicts
 from dagster.utils.error import SerializableErrorInfo
 
 
@@ -70,9 +65,19 @@ class UserFailureData(namedtuple("_UserFailureData", "label description metadata
 
 @whitelist_for_serdes
 class StepOutputData(
-    namedtuple("_StepOutputData", "step_output_handle intermediate_materialization type_check_data")
+    namedtuple(
+        "_StepOutputData",
+        "step_output_handle intermediate_materialization type_check_data address version",
+    )
 ):
-    def __new__(cls, step_output_handle, intermediate_materialization=None, type_check_data=None):
+    def __new__(
+        cls,
+        step_output_handle,
+        intermediate_materialization=None,
+        type_check_data=None,
+        address=None,
+        version=None,
+    ):
         return super(StepOutputData, cls).__new__(
             cls,
             step_output_handle=check.inst_param(
@@ -84,6 +89,8 @@ class StepOutputData(
                 (AssetMaterialization, Materialization),
             ),
             type_check_data=check.opt_inst_param(type_check_data, "type_check_data", TypeCheckData),
+            address=check.opt_str_param(address, "address"),
+            version=check.opt_str_param(version, "version"),
         )
 
     @property
@@ -131,13 +138,20 @@ class StepInputSourceType(Enum):
     MULTIPLE_OUTPUTS = "MULTIPLE_OUTPUTS"
     CONFIG = "CONFIG"
     DEFAULT_VALUE = "DEFAULT_VALUE"
+    CACHED_OUTPUT = "CACHED_OUTPUT"
 
 
 class StepInput(
-    namedtuple("_StepInput", "name dagster_type source_type source_handles config_data")
+    namedtuple("_StepInput", "name dagster_type source_type source_handles config_data addresses")
 ):
     def __new__(
-        cls, name, dagster_type=None, source_type=None, source_handles=None, config_data=None,
+        cls,
+        name,
+        dagster_type=None,
+        source_type=None,
+        source_handles=None,
+        config_data=None,
+        addresses=None,
     ):
         return super(StepInput, cls).__new__(
             cls,
@@ -148,6 +162,9 @@ class StepInput(
                 source_handles, "source_handles", of_type=StepOutputHandle
             ),
             config_data=config_data,  # can be any type
+            addresses=check.opt_dict_param(
+                addresses, "addresses", key_type=StepOutputHandle, value_type=str
+            ),
         )
 
     @property
@@ -173,6 +190,10 @@ class StepInput(
     def is_from_multiple_outputs(self):
         return self.source_type == StepInputSourceType.MULTIPLE_OUTPUTS
 
+    @property
+    def is_from_cached_output(self):
+        return self.source_type == StepInputSourceType.CACHED_OUTPUT and self.addresses is not None
+
     @property
     def dependency_keys(self):
         return {handle.step_key for handle in self.source_handles}
@@ -196,7 +217,7 @@ class ExecutionStep(
         "_ExecutionStep",
         (
             "pipeline_name key_suffix step_inputs step_input_dict step_outputs step_output_dict "
-            "compute_fn kind solid_handle logging_tags tags hook_defs"
+            "compute_fn kind solid_handle solid logging_tags tags hook_defs"
         ),
     )
 ):
@@ -211,9 +232,8 @@ class ExecutionStep(
         solid_handle,
         solid,
         logging_tags=None,
-        tags=None,
-        hook_defs=None,
     ):
+
         return super(ExecutionStep, cls).__new__(
             cls,
             pipeline_name=check.str_param(pipeline_name, "pipeline_name"),
@@ -222,9 +242,13 @@ class ExecutionStep(
             step_input_dict={si.name: si for si in step_inputs},
             step_outputs=check.list_param(step_outputs, "step_outputs", of_type=StepOutput),
             step_output_dict={so.name: so for so in step_outputs},
-            compute_fn=check.callable_param(compute_fn, "compute_fn"),
+            compute_fn=check.callable_param(
+                compute_fn, "compute_fn"
+            ),  # Compute_fn is the compute function for the step.
+            #     Not to be confused with the compute_fn of the passed in solid.
             kind=check.inst_param(kind, "kind", StepKind),
             solid_handle=check.inst_param(solid_handle, "solid_handle", SolidHandle),
+            solid=check.inst_param(solid, "solid", Solid),
             logging_tags=merge_dicts(
                 {
                     "step_key": str(solid_handle) + "." + key_suffix,
@@ -234,8 +258,8 @@ class ExecutionStep(
                 },
                 check.opt_dict_param(logging_tags, "logging_tags"),
             ),
-            tags=check.opt_inst_param(tags, "tags", frozentags),
-            hook_defs=check.opt_set_param(hook_defs, "hook_defs", of_type=HookDefinition),
+            tags=solid.tags,
+            hook_defs=solid.hook_defs,
         )
 
     @property
