@@ -9,7 +9,7 @@ from click.testing import CliRunner
 
 from dagster.cli.pipeline import execute_execute_command, pipeline_execute_command
 from dagster.core.errors import DagsterInvariantViolationError
-from dagster.core.test_utils import instance_for_test
+from dagster.core.test_utils import instance_for_test, new_cwd
 from dagster.utils import file_relative_path, merge_dicts
 
 from .test_cli_commands import (
@@ -83,6 +83,13 @@ def test_execute_mode_command():
         assert double_adder_result
 
 
+def test_empty_execute_command():
+    runner = CliRunner()
+    result = runner.invoke(pipeline_execute_command, [])
+    assert result.exit_code == 2
+    assert "Must specify a python file or module name" in result.output
+
+
 def test_execute_preset_command():
     with instance_for_test():
         runner = CliRunner()
@@ -199,10 +206,7 @@ def test_more_than_one_pipeline():
     with instance_for_test() as instance:
         with pytest.raises(
             UsageError,
-            match=re.escape(
-                "Must provide --pipeline as there is more than one pipeline in bar. "
-                "Options are: ['baz', 'foo']."
-            ),
+            match=re.escape("Must provide --pipeline as there is more than one pipeline in bar. "),
         ):
             execute_execute_command(
                 kwargs={
@@ -500,3 +504,23 @@ def test_execute_subset_pipeline_invalid():
         )
         assert result.exit_code == 1
         assert "No qualified solids to execute found for solid_selection" in str(result.exception)
+
+
+def test_empty_working_directory():
+    runner = CliRunner()
+    import os
+
+    with instance_for_test() as instance:
+        with new_cwd(os.path.dirname(__file__)):
+            result = runner.invoke(
+                pipeline_execute_command,
+                [
+                    "-f",
+                    file_relative_path(__file__, "file_with_local_import.py"),
+                    "-a",
+                    "foo_pipeline",
+                ],
+            )
+            assert result.exit_code == 0
+            runs = instance.get_runs()
+            assert len(runs) == 1
